@@ -1,7 +1,10 @@
+from unum import Unum
+
 from robotpy_toolkit_7407.motor import PIDMotor
 from robotpy_toolkit_7407.oi.joysticks import JoystickAxis
 from robotpy_toolkit_7407.subsystem import Subsystem
 from robotpy_toolkit_7407.utils import logger
+from robotpy_toolkit_7407.utils.units import rad, m
 
 
 class DifferentialDrivetrain(Subsystem):
@@ -9,6 +12,7 @@ class DifferentialDrivetrain(Subsystem):
     m_right: PIDMotor = None
     axis_x: JoystickAxis = None
     axis_y: JoystickAxis = None
+    gear_ratio: Unum = rad/m
 
     def init(self):
         logger.info("initializing differential drivetrain", "[differential_drivetrain]")
@@ -20,6 +24,6 @@ class DifferentialDrivetrain(Subsystem):
         self.m_left.set_raw_output(left)
         self.m_right.set_raw_output(right)
 
-    def set_motor_velocity(self, left: float, right: float):
-        self.m_left.set_target_velocity(left)
-        self.m_right.set_target_velocity(right)
+    def set_motor_velocity(self, left_vel: Unum, right_vel: Unum):
+        self.m_left.set_target_velocity(left_vel * self.gear_ratio)
+        self.m_right.set_target_velocity(right_vel * self.gear_ratio)
